// hardcodet.net Logging
// Copyright (c) 2009 Philipp Sumi
// Contact and Information: http://www.hardcodet.net
//
// This library is free software; you can redistribute it and/or
// modify it in any way you see fit as long as this copyright
// notice is not being removed.
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
// OTHER DEALINGS IN THE SOFTWARE.
//
// THIS COPYRIGHT NOTICE MAY NOT BE REMOVED FROM THIS FILE



using System;
using System.Diagnostics;

namespace Hardcodet.Util.Logging
{
  /// <summary>
  /// Common interface of an arbitrary implementation that provides
  /// logging capabilities.
  /// </summary>
  public interface ILogger
  {
    
    /// <summary>
    /// Logs an informational message (<see cref="TraceEventType.Information"/>).
    /// </summary>
    /// <param name="message">The message to be logged.</param>
    void Log(string message);

    

    /// <summary>
    /// Logs an exception with a logging level of
    /// <see cref="TraceEventType.Error"/>.
    /// </summary>
    /// <param name="exception">Exception to be logged.</param>
    void Log(Exception exception);



    /// <summary>
    /// Logs an error with an additional message with a logging level of
    /// <see cref="TraceEventType.Error"/>.
    /// </summary>
    /// <param name="message">Additional information regarding the
    /// logged exception.</param>
    /// <param name="exception">Exception to be logged.</param>
    void Log(string message, Exception exception);



    /// <summary>
    /// Logs a message with a given logging severity.
    /// </summary>
    /// <param name="message">The message to be logged.</param>
    /// <param name="severity">Logging category.</param>
    void Log(string message, TraceEventType severity);



    /// <summary>
    /// Logs an exception with a given logging severity and an
    /// additional message.
    /// </summary>
    /// <param name="message">Additional information regarding the
    /// logged exception.</param>
    /// <param name="exception">Exception to be logged.</param>
    /// <param name="severity">Logging category.</param>
    void Log(string message, Exception exception, TraceEventType severity);

    
    /// <summary>
    /// Creates a new log entry based on a given log item.
    /// </summary>
    /// <param name="item">Encaspulates logging information.</param>
    /// <exception cref="ArgumentNullException">If <paramref name="item"/>
    /// is a null reference.</exception>
    void Log(LogItem item);
  }
}